# all modules
from . import knn
from . import utils
from . import classes

# version
__version__ = "0.0.1"